@@ -31,9 +31,13 @@ def prepare_current_repo(work_dir: Path) -> Path:
     return dst_dir
 
 
-def compile_proto_file(output_dir: Path, proto_file_name: str) -> None:
-    options = [f"-I{output_dir}", f"--python_out={output_dir}", f"--grpc_python_out={output_dir}"]
-    os.system(f"python -m grpc_tools.protoc {' '.join(options)} {proto_file_name}")
+def compile_proto_file(work_dir: Path, output_dir: Path,
+                       proto_file_name: str) -> None:
+    """Compile protobuf to pb2 & pb2_grpc files"""
+    options = [f"-I{work_dir}", f"--python_out={work_dir}",
+               f"--grpc_python_out={work_dir}"]
+    proto_path = output_dir / proto_file_name
+    os.system(f"python -m grpc_tools.protoc {' '.join(options)} {proto_path}")
 
 
 def compile_client_file(proto_path: Path, service_name: str):
@@ -82,7 +86,6 @@ def create_config_file(config_path: Path):
 
 # noinspection PyTypeChecker
 def create_init_file(init_path: Path):
-
     # get custom imports
     custom_imports = []
     try:
@@ -144,7 +147,7 @@ def add_service(repo_name: str, service: str, target_dir: str) -> None:
         dst_proto_path,
     )
 
-    compile_proto_file(dst_dir, proto_file_name)
+    compile_proto_file(work_dir, dst_dir, proto_file_name)
     compile_client_file(dst_proto_path, service)
     os.system(f"pb2py {dst_dir / f'{service}_pb2.py'} > {dst_dir / f'{service}_schema.py'}")
     create_init_file(dst_dir.parent / "__init__.py")
@@ -175,6 +178,7 @@ def build_service() -> None:
             for i in filenames:
                 file = proto_dir / i
                 if file.suffix == ".proto":
-                    command = base_command.format(dir=proto_dir, file=i)
+                    command = base_command.format(dir=current_dir,
+                                                  file=proto_dir / i)
                     typer.echo(command)
                     os.system(command)
